@@ -161,7 +161,7 @@ SEG *
 }
 
 #ifdef INTERBASE_COORDS
-#define MIN_LOWER 0l
+#define MIN_LOWER INT_MIN
 #else
 #define MIN_LOWER 1l
 #endif
@@ -207,18 +207,25 @@ int get_int(char **strp, int32 *result) {
   }
 
   if (long_result < MIN_LOWER) {
+    // when INTERBASE_COORDS is set, on machines where
+    // sizeof(long int) == sizeof(int32) this block won't be executed because
+    // strtol() will return ERANGE
     ereport(ERROR,
             (errcode(ERRCODE_SYNTAX_ERROR),
              errmsg("bad bioseg representation"),
-             errdetail("integer %ld at: %s is out of range - must be >= %ld", long_result, *strp, MIN_LOWER)));
+             errdetail("integer %ld at: %s is out of range - must be >= %d",
+                       long_result, *strp, MIN_LOWER)));
     return 0;
   }
 
   if (long_result > INT_MAX) {
+    // on machines where sizeof(long int) == sizeof(int32) this won't happen
+    // because strtol() will return ERANGE
     ereport(ERROR,
             (errcode(ERRCODE_SYNTAX_ERROR),
              errmsg("bad bioseg representation"),
-             errdetail("integer %ld at: %s is out of range - must be <= %d", long_result, *strp, UINT_MAX)));
+             errdetail("integer %ld at: %s is out of range - must be <= %d",
+                       long_result, *strp, INT_MAX)));
     return 0;
   }
 
